@@ -228,6 +228,7 @@ static GConfEnumStringPair placement_lookup[] = {
 	{ GNOME_BG_PLACEMENT_SCALED,      "scaled" },
 	{ GNOME_BG_PLACEMENT_ZOOMED,      "zoom" },
 	{ GNOME_BG_PLACEMENT_TILED,       "wallpaper" },
+	{ GNOME_BG_PLACEMENT_SPANNED,       "spanned" },
 	{ 0, NULL }
 };
 
@@ -733,6 +734,9 @@ get_scaled_pixbuf (GnomeBGPlacement placement,
 #endif
 	
 	switch (placement) {
+	case GNOME_BG_PLACEMENT_SPANNED:
+                new = pixbuf_scale_to_fit (pixbuf, width, height);
+		break;
 	case GNOME_BG_PLACEMENT_ZOOMED:
 		new = pixbuf_scale_to_min (pixbuf, width, height);
 		break;
@@ -787,6 +791,9 @@ draw_image_area (GnomeBGPlacement  placement,
 	case GNOME_BG_PLACEMENT_SCALED:
 		pixbuf_blend (scaled, dest, 0, 0, w, h, x + area->x, y + area->y, 1.0);
 		break;
+	case GNOME_BG_PLACEMENT_SPANNED:
+		pixbuf_blend (scaled, dest, 0, 0, w, h, x, y, 1.0);
+		break;
 	default:
 		g_assert_not_reached ();
 		break;
@@ -865,7 +872,7 @@ gnome_bg_draw (GnomeBG *bg,
 	if (!bg)
 		return;
 
-	if (is_root) {
+	if (is_root && (bg->placement != GNOME_BG_PLACEMENT_SPANNED)) {
 		draw_color_each_monitor (bg, dest, screen);
 		draw_each_monitor (bg, dest, screen);
 	} else {
@@ -1639,11 +1646,13 @@ get_as_pixbuf_for_size (GnomeBG    *bg,
 	else {
 		GdkPixbufFormat *format;
 		GdkPixbuf *pixbuf;
+                gchar *tmp;
 
 		/* If scalable choose maximum size */
 		format = gdk_pixbuf_get_file_info (filename, NULL, NULL);
+                tmp = gdk_pixbuf_format_get_name (format);
 		if (format != NULL &&
-		    strcmp (gdk_pixbuf_format_get_name (format), "svg") == 0 &&
+		    strcmp (tmp, "svg") == 0 &&
 		    (best_width > 0 && best_height > 0) &&
 		    (bg->placement == GNOME_BG_PLACEMENT_FILL_SCREEN ||
 		     bg->placement == GNOME_BG_PLACEMENT_SCALED ||
@@ -1651,6 +1660,7 @@ get_as_pixbuf_for_size (GnomeBG    *bg,
 			pixbuf = gdk_pixbuf_new_from_file_at_size (filename, best_width, best_height, NULL);
 		else
 			pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+                g_free (tmp);
 
 		if (pixbuf)
 			file_cache_add_pixbuf (bg, filename, pixbuf);
